@@ -32,6 +32,12 @@ class UpdateOperation(str, Enum):
 EdgeResolverType = T.TypeVar("EdgeResolverType", bound="Resolver")
 
 
+class DependencyInfo(BaseModel):
+    fields: T.List[str]
+    ignore_if_admin: bool
+    ignore_if_no_auth_id: bool
+
+
 class Resolver(BaseModel, T.Generic[NodeType]):
     """Can construct an EdgeQL query string from this!"""
 
@@ -55,6 +61,7 @@ class Resolver(BaseModel, T.Generic[NodeType]):
     _fields_to_return: T.Set[str] = PrivateAttr(None)
     _fields_to_include: T.Set[str] = PrivateAttr(default_factory=set)
 
+    _field_dependency_map: T.ClassVar[T.Dict[str, DependencyInfo]] = {}
     """PROPERTIES"""
 
     @classmethod
